% EwE_MonteCarlo_01182015
% by Jim Ruzicka
% generate and evaluate Monte Carlo EwE models within each parameter PEDIGREE
% takes:
%       readFile            EwE model as .csv file
%           dat
%           EwEResult
%           PEDIGREE
% calls:
%       f_read_EwE_csv_01122015
%       f_AggregateResults_EwE_01122015
%       f_EwEinterval_MonteCarlo_04092014
%       f_EwEnormal_MonteCarlo_04092014
%           f_DietPreference_Readjust_04052014
%           f_EE_MonteCarlo_04092014
% revision date: 1-18-2015





% *************************************************************************
% STEP 1: set operating parameters-----------------------------------------
% step 1a: save file name
% SaveFile_directory = '/Users/ruzickaj/Documents/3_FoodWeb_models/9_CGoA/';
% saveFile           = ['CGoAprs_MCnorm_' date '.mat'];
% SaveFile_directory = '/Users/ruzickaj/Documents/3_FoodWeb_models/1_NCC/NCCprs_MammalAgg/';
% saveFile           = ['NCCprs_MammalAgg_MCnorm_' date '.mat'];
% SaveFile_directory = '/Users/ruzickaj/Documents/3_FoodWeb_models/11_GB/';
% saveFile           = ['GBprs_MCnorm_' date '.mat'];

SaveFile_directory = '/Users/ruzickaj/Documents/3_FoodWeb_models/4_TEST/';
saveFile           = ['TEST_MCnorm_' date '.mat'];

saveFile           = [SaveFile_directory saveFile];

% step 1b: target number of models wanted & number of trials to run
num_trials         = 1000; % number of good models to obtain
maximum_trials     = 50000000; % maximum number of trials

% step 1c: set distribution_type
distribution_type = 'normal'; % 'normal' or 'uniform'





% *************************************************************************
% STEP 2: load & aggregate EwE results-------------------------------------
% step 2a: define model to work with
% ReadFile_directory         = '/Users/ruzickaj/Documents/3_FoodWeb_models/9_CGoA/';
% readFile                   = 'CGoAprs_12023011.csv';
% ReadFile_directory         = '/Users/ruzickaj/Documents/3_FoodWeb_models/1_NCC/NCCprs_MammalAgg/';
% readFile                   = 'NCCprs_MammalAgg_12272012.csv';
% ReadFile_directory         = '/Users/ruzickaj/Documents/3_FoodWeb_models/11_GB/';
% readFile                   = 'GBprs_FullRes_06062012.csv';

ReadFile_directory         = '/Users/ruzickaj/Documents/3_FoodWeb_models/4_TEST/';
readFile                   = 'TESTmodel_01182015.csv';





readFile                   = [ReadFile_directory readFile];

% step 2b: load EwE model from K-path (.csv format)
[dat]                      = f_read_EwE_csv_01122015(readFile);

% step 2c: aggregate model results & prep EwEResult for analysis
[EwEResult, PEDIGREE]      = f_AggregateResults_EwE_01122015(dat);





% *************************************************************************
% STEP 3: set-up-----------------------------------------------------------
PEDIGREE.STD_scaler              = 1; % STD range of acceptable drawing interval
PEDIGREE.SamplingScale           = 1; % Bigger number makes STD range tighter; SamplingScale = 1 assumes the valid parameter interval represents +/- 2 STD_scaler (98% of values)
PEDIGREE.SamplingScale_Diet      = 1;
PEDIGREE.SamplingScale_Fisheries = 1;

EE_MAXallowed              = PEDIGREE.PedigreeParameters(:, 1);
[diet_rows diet_clms]      = size(EwEResult.Diet);
param_rows                 = diet_rows - 2; % subtract 1 for header and 1 for import diet
num_fisheries              = EwEResult.num_fisheries;

MonteCarlo_interval        = f_EwEinterval_MonteCarlo_04092014(EwEResult, PEDIGREE);



% *************************************************************************
% STEP 4: generate & evaluate random models--------------------------------
% step 4a: initialize counters
trial_count = 0;
trial_good  = 0;
bad_groups  = [];
bad_EE      = [];

while trial_good < num_trials && trial_count < maximum_trials

    % step 4b: generate 1 random EwE model (NOT necessarily balanced)
    randomEwE   = f_EwEnormal_MonteCarlo_04092014(EwEResult, MonteCarlo_interval, PEDIGREE);
    trial_count = trial_count + 1;

    % step 4c: store model if it is balanced
    evaluate_EE = (EE_MAXallowed - randomEwE.EcotrophicEfficiency); % evaluate_EE < 0 when EE in random model exceeds max allwoed EE
    min_EE      = min(evaluate_EE);
    looky_MaxEE = find(evaluate_EE == min_EE); % which group had the largest EE
    
    if min_EE >= 0
    
        % store random model
        trial_good                                                                = trial_good + 1;
        MonteCarloStore.Biomass(1:param_rows, trial_good)                         = randomEwE.Biomass;
        MonteCarloStore.PB(1:param_rows, trial_good)                              = randomEwE.PB;
        MonteCarloStore.QB(1:param_rows, trial_good)                              = randomEwE.QB;
        MonteCarloStore.PQ(1:param_rows, trial_good)                              = randomEwE.PQ;
        MonteCarloStore.AE(1:param_rows, trial_good)                              = randomEwE.AE;
        MonteCarloStore.BA(1:param_rows, trial_good)                              = randomEwE.BA;        
        MonteCarloStore.EM(1:param_rows, trial_good)                              = randomEwE.EM;
        MonteCarloStore.Landings(1:param_rows, 1:num_fisheries, trial_good)       = randomEwE.Landings;
        MonteCarloStore.Discards(1:param_rows, 1:num_fisheries, trial_good)       = randomEwE.Discards;        
        MonteCarloStore.Production(1:param_rows, trial_good)                      = randomEwE.Production;
        MonteCarloStore.TotalConsumption(1:param_rows, trial_good)                = randomEwE.TotalConsumption;        
        MonteCarloStore.diet(1:diet_rows, 1:diet_clms, trial_good)                = randomEwE.Diet;
        MonteCarloStore.Consumption(1:(diet_rows-1), 1:(diet_clms-1), trial_good) = randomEwE.Consumption;
        MonteCarloStore.EcotrophicEfficiency(1:param_rows, trial_good)            = randomEwE.EcotrophicEfficiency; % one row added to end for fisheries EE
        MonteCarloStore.EcotrophicEfficiency_predation(1:param_rows, trial_good)  = randomEwE.EcotrophicEfficiency_predation; % one row added to end for fisheries EE
        MonteCarloStore.EcotrophicEfficiency_BA(1:param_rows, trial_good)         = randomEwE.EcotrophicEfficiency_BA; % one row added to end for fisheries EE        
        MonteCarloStore.EcotrophicEfficiency_EM(1:param_rows, trial_good)         = randomEwE.EcotrophicEfficiency_EM; % one row added to end for fisheries EE
        
        % step 4d: save workspace
        save(saveFile)
     
%     else
%         % store failed groups for evaluation
% %         looky_bad = find(evaluate_EE < 0);
% %         bad_EE = [bad_EE; randomEwE.EcotrophicEfficiency(looky_bad)];
% %         bad_groups = [bad_groups; looky_bad];
%         
%         bad_EE = [bad_EE; randomEwE.EcotrophicEfficiency(looky_MaxEE)];
%         bad_groups = [bad_groups; looky_MaxEE];
%         
        
        
        
        
    end
    
%     display(['tested models: ' num2str(trial_count) '  good models: ' num2str(trial_good)  '  good fraction: ' num2str(trial_good/trial_count) ' max EE: ' num2str(max(randomEwE.EcotrophicEfficiency))])

end % (while trial_good < num_trials && trial_count < maximum_trials)

% hist(bad_groups, 1:param_rows)
% set(gca,'xtick',(1:param_rows))



% *************************************************************************
% this is useful for evaluating errors*************************************
% step 5a: ECOTRAN conversion ---------------------------------------------
[ECOTRAN] = ECOTRANuncertainty_04092014(EwEResult, MonteCarloStore); % (QQQ error-check, dummy fisheries give clms of mostly NaNs)

% FIND BAD MODELS; ROWS; CLMS
Build_Badmodels = [];
Build_Smallrows = [];
Build_Bigrows   = [];
Build_Smallclms = [];
Build_Bigclms   = [];

for model_loop = 1:73
    current_BioenergeticBudget_ProductionDetail = ECOTRAN.BioenergeticBudget_ProductionDetail(:,:,model_loop);
    [TooBig_rows, TooBig_clms] = find(current_BioenergeticBudget_ProductionDetail > 1);
    [TooSmall_rows, TooSmall_clms] = find(current_BioenergeticBudget_ProductionDetail < 0);
    
    if ~isempty(TooBig_clms) || ~isempty(TooSmall_clms)
        Build_Badmodels = [Build_Badmodels; model_loop];
    end
    
    if ~isempty(TooSmall_rows)
        Build_Smallrows = [Build_Smallrows; TooSmall_rows];
    end
    
    if ~isempty(TooBig_rows)
        Build_Bigrows = [Build_Bigrows; TooBig_rows];
    end
    
    
    if ~isempty(TooSmall_clms)
        Build_Smallclms = [Build_Smallclms; TooSmall_clms];
    end
    
    if ~isempty(TooBig_clms)
        Build_Bigclms = [Build_Bigclms; TooBig_clms];
    end
    
end

Build_Smallrows = unique(Build_Smallrows);
Build_Bigrows   = unique(Build_Bigrows);
Build_Smallclms = unique(Build_Smallclms);
Build_Bigclms   = unique(Build_Bigclms);

% STEP OPTIONAL: plotting of MonteCarlo parameter distributions------------
target_grp = [10 11 12 13];
target_grp = target_grp - 3; % subtract 3 because of nutrients
target_parameter = 'PB'; % choose parameter to plot: 'biomass', 'production', 'PB', 'QB', 'PQ', 'AE', 'Landings', 'Discards' (QQQ later to add BA, EM, diet, consumption)
p_MonteCarlo_EwEDistribution_09062013(EwEResult, PEDIGREE, MonteCarloStore, target_grp, target_parameter)





% end m-file***************************************************************