function [EwEResult, PEDIGREE] = f_AggregateResults_EwE_01122015(dat)
% prepare EwE model and aggregate functional groups
% by Jim Ruzicka
% calculates production-weighted averages of physiological constants
% corrects for technique of defining egg production as a detritus term:
%     (since EwE does not distinguish between feces and "other mortality" detritus pools, AE must be adjusted upwards to account for eggs generated from feces detritus)
% detritus production = detritus consumption rate
% PB is recalculated based on production value that includes the detritus import rate (i.e., egg production)
% takes:
%		dat
% calls:
%		none
% returns (model):
%    EwEResult.AggLabel                         group labels (vertical cell vector)
%    EwEResult.GroupType                        group type code in aggregated model (vertical vector)
%    EwEResult.FullResNums                      group numbers in fully-resolved model (vector)
%    EwEResult.EwE_code
%    EwEResult.AggNumber                        aggregate group number (vertical vector)
%    EwEResult.num_PrimaryProducers
%    EwEResult.num_eggs
%    EwEResult.num_detritus
%    EwEResult.num_EggsAndDetritus
%    EwEResult.num_NitrogenNutrients
%    EwEResult.num_fisheries
%    EwEResult.num_plgcBacteria
%    EwEResult.num_bnthBacteria
%    EwEResult.num_Bacteria
%    EwEResult.Biomass                          (vertical vector)
%    EwEResult.BiomassWOegg                     (vertical vector)
%    EwEResult.Production                       summed production rate (t/km2/yr) (vertical vector)
%    EwEResult.ProductionWOegg                  (vertical vector)
%    EwEResult.PB                               (vertical vector)
%    EwEResult.QB                               (vertical vector)
%    EwEResult.PQ                               (vertical vector)
%    EwEResult.AE                               weighted mean assimilation efficiency (vertical vector)
%    EwEResult.TL                               weighted mean TL (vertical vector)
%    EwEResult.EwE_EE                           weighted mean EE (vertical vector)
%    EwEResult.BA                               (vertical vector)
%    EwEResult.EM                               (vertical vector)
%    EwEResult.Diet                             (row 1 = predator code number, column 1 = prey code number)
%    EwEResult.Consumption                      last row is import consumption (QQQ re-check this) (array) 
%    EwEResult.ImportConsumption
%    EwEResult.TotalConsumption                 total consumption by each aggregated predator group (includes import consumption) (horizontal vector)
%    EwEResult.EwE_DetritusFate
%    EwEResult.EwE_EggFractions
%    EwEResult.DetritusFate_feces
%    EwEResult.DetritusFate_senescence
%    EwEResult.ExcretionFate
%    EwEResult.ProductionLossScaler
%    EwEResult.RetentionScaler
%    EwEResult.EggProduction_forced
%    EwEResult.Metabolism_forced
%    EwEResult.PelagicBacterialReduction
%    EwEResult.BenthicBacterialReduction
%    EwEResult.Oxidation_NH4
%    EwEResult.PhytoUptake_NH4
%    EwEResult.PhytoUptake_NO3
%    EwEResult.AggLabel_nutrients
%    EwEResult.GroupType_nutrients
%    EwEResult.AggLabel_fisheries
%    EwEResult.Landings
%    EwEResult.Discards
%    EwEResult.Biomass_fisheries
%    EwEResult.BiomassWOegg_fisheries
%    EwEResult.Production_fisheries
%    EwEResult.ProductionWOegg_fisheries
%    EwEResult.PB_fisheries
%    EwEResult.QB_fisheries
%    EwEResult.PQ_fisheries
%    EwEResult.AE_fisheries
%    EwEResult.EwE_EE_fisheries
%    EwEResult.BA_fisheries
%    EwEResult.EM_fisheries
%    EwEResult.TL_fisheries
%    EwEResult.Landings_fisheries
%    EwEResult.Discards_fisheries
%    EwEResult.DetritusFate_feces_fisheries
%    EwEResult.DetritusFate_senescence_fisheries
%    EwEResult.ExcretionFate_fisheries
%    EwEResult.ProductionLossScaler_fisheries
%    EwEResult.RetentionScaler_fisheries
%    EwEResult.EggProduction_forced_fisheries
%    EwEResult.Metabolism_forced_fisheries
%    EwEResult.GroupTypeDef_ANYNitroNutr                  GroupType definitions
%    EwEResult.GroupTypeDef_NO3                           GroupType definitions
%    EwEResult.GroupTypeDef_plgcNH4                       GroupType definitions
%    EwEResult.GroupTypeDef_bnthNH4                       GroupType definitions
%    EwEResult.GroupTypeDef_ANYPrimaryProd                GroupType definitions
%    EwEResult.GroupTypeDef_LrgPhyto
%    EwEResult.GroupTypeDef_SmlPhyto
%    EwEResult.GroupTypeDef_Macrophytes
%    EwEResult.GroupTypeDef_ANYConsumer
%    EwEResult.GroupTypeDef_ConsumPlgcPlankton
%    EwEResult.GroupTypeDef_ConsumPlgcNekton
%    EwEResult.GroupTypeDef_ConsumPlgcWrmBlood
%    EwEResult.GroupTypeDef_ConsumBntcInvert
%    EwEResult.GroupTypeDef_ConsumBntcVert
%    EwEResult.GroupTypeDef_ConsumBnthWrmBlood
%    EwEResult.GroupTypeDef_eggs
%    EwEResult.GroupTypeDef_ANYDetritus
%    EwEResult.GroupTypeDef_terminalPlgcDetr
%    EwEResult.GroupTypeDef_offal
%    EwEResult.GroupTypeDef_terminalBnthDetr
%    EwEResult.GroupTypeDef_EM
%    EwEResult.GroupTypeDef_BA
%    EwEResult.GroupTypeDef_fishery
%    EwEResult.GroupTypeDef_import
%    EwEResult.GroupTypeDef_plgcBacteria
%    EwEResult.GroupTypeDef_bnthBacteria
% returns (Pedigree)
%    PEDIGREE.PhysiologyScaler
%    PEDIGREE.BiomassScaler
%    PEDIGREE.FisheriesScaler
%    PEDIGREE.DietScaler
%    PEDIGREE.BAScaler
%    PEDIGREE.EMScaler
%    PEDIGREE.DiscardScaler
%    PEDIGREE.minBiomass
%    PEDIGREE.minPhysiology
%    PEDIGREE.PedigreeParameters
%    PEDIGREE.PedigreeLandings
%    PEDIGREE.PedigreeDiscards
%    PEDIGREE.PedigreeDiet
%    PEDIGREE.PedigreeDietPrefRules
%    PEDIGREE.PreyGuild_name
%    PEDIGREE.PreyGuild_code
% revision date: 01-12-2015

% QQQ to check and to do in future:
% 1) need to allow for horizontal aggregation of EwE_EggFractions
% 2) warning in diet agg section ---> still need to NOT aggregate eggs and consumers (just use a warning) <--- what is this for?
% 3) % trophic group numbers in fully-resolved model (QQQ take off fisheries rows??)
% 4) many of these EwEResult returns are not needed, trim them out
% 5) add predation return to EwEResult





% *************************************************************************
% STEP 1: get info from .dat-----------------------------------------------
% step 1a: get info from "EcotranType" worksheet
NumberCodes                     = dat.EcotranNumberCode; % code numbers of fully resolved trophic groups (vertical vector)
GroupTypes                      = dat.EcotranGroupType; % (NOTE: BA & EM rows not read in from this sheet)
AggCodes                        = dat.AggCode; % aggregate group code numbers
AggName                         = dat.AggEwEName; % non-aggregated vector of agg group names

GroupTypeDef_ANYNitroNutr       = dat.GroupTypeDef_ANYNitroNutr;
GroupTypeDef_NO3                = dat.GroupTypeDef_NO3;
GroupTypeDef_plgcNH4            = dat.GroupTypeDef_plgcNH4;
GroupTypeDef_bnthNH4            = dat.GroupTypeDef_bnthNH4;
GroupTypeDef_ANYPrimaryProd     = dat.GroupTypeDef_ANYPrimaryProd;
GroupTypeDef_LrgPhyto           = dat.GroupTypeDef_LrgPhyto;
GroupTypeDef_SmlPhyto           = dat.GroupTypeDef_SmlPhyto;
GroupTypeDef_Macrophytes        = dat.GroupTypeDef_Macrophytes;
GroupTypeDef_ANYConsumer        = dat.GroupTypeDef_ANYConsumer;
GroupTypeDef_ConsumPlgcPlankton = dat.GroupTypeDef_ConsumPlgcPlankton;
GroupTypeDef_ConsumPlgcNekton   = dat.GroupTypeDef_ConsumPlgcNekton;
GroupTypeDef_ConsumPlgcWrmBlood = dat.GroupTypeDef_ConsumPlgcWrmBlood;
GroupTypeDef_ConsumBntcInvert   = dat.GroupTypeDef_ConsumBntcInvert;
GroupTypeDef_ConsumBntcVert     = dat.GroupTypeDef_ConsumBntcVert;
GroupTypeDef_ConsumBnthWrmBlood = dat.GroupTypeDef_ConsumBnthWrmBlood;
GroupTypeDef_eggs               = dat.GroupTypeDef_eggs;
GroupTypeDef_ANYDetritus        = dat.GroupTypeDef_ANYDetritus;
GroupTypeDef_terminalPlgcDetr   = dat.GroupTypeDef_terminalPlgcDetr;
GroupTypeDef_offal              = dat.GroupTypeDef_offal;
GroupTypeDef_terminalBnthDetr   = dat.GroupTypeDef_terminalBnthDetr;
GroupTypeDef_BA                 = dat.GroupTypeDef_BA;
GroupTypeDef_EM                 = dat.GroupTypeDef_EM;
GroupTypeDef_fishery            = dat.GroupTypeDef_fishery;
GroupTypeDef_import             = dat.GroupTypeDef_import;
GroupTypeDef_plgcBacteria       = dat.GroupTypeDef_plgcBacteria;
GroupTypeDef_bnthBacteria       = dat.GroupTypeDef_bnthBacteria;

% step 1b: get info from "EcotranRecycling" worksheet
temp_BA                         = dat.BA; % prefix with "temp" becaue this is the pre-aggregeted state
temp_EM                         = dat.EM;
temp_EggProduction_forced       = dat.EggProduction; % defined egg, gamete, or live-birth production (not defined as EwE detritus) (QQQ for future)
temp_Metabolism_forced          = dat.Metabolism; % defined metabolism (not defined by EwE parameters) (QQQ for future)
temp_DetritusFate_feces         = dat.DetritusFate_feces;
temp_DetritusFate_senescence    = dat.DetritusFate_senescence;
temp_ExcretionFate              = dat.ExcretionFate;
temp_ProductionLossScaler       = dat.ProductionLossScaler;
temp_RetentionScaler            = dat.RetentionScaler;
temp_FunctionalResponseParams   = dat.FunctionalResponseParams;
temp_FunctionalResponse_matrix  = dat.FunctionalResponse_matrix;

% step 1c: prep GroupType codes and EcotranRecycling terms to align with resolved model EwE numbers (remove nutrient and BA & EM rows from EcotranRecycling variables; BA & EM rows are probably already Null)
looky_nutrients                                                  = find(floor(GroupTypes) == GroupTypeDef_ANYNitroNutr);
looky_BAEM                                                       = find(GroupTypes == GroupTypeDef_BA | GroupTypes == GroupTypeDef_EM);
GroupType_nutrients                                              = GroupTypes(looky_nutrients);
AggLabel_nutrients                                               = AggName(looky_nutrients);
NumberCodes([looky_nutrients; looky_BAEM])                       = [];
GroupTypes([looky_nutrients; looky_BAEM])                        = [];
AggCodes([looky_nutrients; looky_BAEM])                          = [];
AggName([looky_nutrients; looky_BAEM])                           = [];
temp_BA([looky_nutrients; looky_BAEM])                           = []; % ECOTRAN recycling terms need nutrient rows to be removed)
temp_EM([looky_nutrients; looky_BAEM])                           = [];
temp_EggProduction_forced([looky_nutrients; looky_BAEM])         = []; 
temp_Metabolism_forced([looky_nutrients; looky_BAEM])            = [];
temp_DetritusFate_feces([looky_nutrients; looky_BAEM], :)        = [];
temp_DetritusFate_senescence([looky_nutrients; looky_BAEM], :)   = [];
temp_ExcretionFate([looky_nutrients; looky_BAEM], :)             = [];
temp_ProductionLossScaler([looky_nutrients; looky_BAEM])         = [];
temp_RetentionScaler([looky_nutrients; looky_BAEM])              = []; % QQQ dont do this???
temp_FunctionalResponseParams([looky_nutrients; looky_BAEM], :)  = []; % QQQ dont do this???
temp_FunctionalResponse_matrix([looky_nutrients; looky_BAEM], :) = []; % QQQ dont do this???
uniqueAggCodes                                                   = unique(AggCodes); % unique aggregate group code numbers

% step 1d: get other EwE parameters
temp_Biomass                 = dat.Biomass; % (vertical vector)
temp_Production              = dat.Production; % production rate (t/km2/yr); (vertical vector)
temp_Production              = temp_Production + dat.DetritusImport; % add DetritusImport to temp_Production; (DetritusImport is probably all 0, used to be used for eggs in old versions)
temp_EwE_DetritusFate        = dat.EwE_DetritusFate; % EwE detritus fate definitions (not the ECOTRAN definitions)
DetritusImport               = dat.DetritusImport; % add egg production rate (= detritus import rate); this is old-style ECOTRAN (obsolete now)
temp_Consumption             = dat.consumption(2:end, 2:end); % trim off header rows
temp_ImportConsumption       = dat.import_consumption(2:end); % (no need to append fisheries on this); trims off header column; (horizontal vector)
temp_TotalConsumption        = sum(temp_Consumption, 1) + temp_ImportConsumption; % sum after trimming off header rows; these values the same as (dat.QB .* dat.Biomass) but also include detritus and fisheries; (horizontal vector)

% step 1e: look for addresses in non-aggregated model
clear looky_* % nutrient and BA & EM row addresses from above are now obsolete
looky_Detritus               = find(floor(GroupTypes) == GroupTypeDef_ANYDetritus);
looky_Eggs                   = find(GroupTypes == GroupTypeDef_eggs);
looky_EggsAndDetritus        = [looky_Detritus; looky_Eggs];
looky_TerminalPlgcDetritus   = find(GroupTypes == GroupTypeDef_terminalPlgcDetr);
looky_TerminalBnthDetritus   = find(GroupTypes == GroupTypeDef_terminalBnthDetr);
looky_fisheries              = find(floor(GroupTypes) == GroupTypeDef_fishery);

% step 1f: counts of groups and group types
num_LivingAndDetritus        = dat.num_LivingAndDetritus;
num_gear                     = dat.num_gear;
num_ResGroups                = dat.num_EwEGroups; % number of fully-resolved groups
num_NitrogenNutrients        = dat.num_NitrogenNutrients;
num_detritus                 = dat.num_detritus;
num_EggsAndDetritus          = dat.num_EggsAndDetritus;
num_eggs                     = dat.num_eggs;
num_AggGroups                = length(uniqueAggCodes); % number of aggregated groups

% step 1g: prep EwE_EggFractions (note that feces are also distributed across "egg detritus" in EwE)
EggsAndDetritus              = [GroupTypes(looky_Detritus); GroupTypes(looky_Eggs)];
[toss, sort_order]           = sort(looky_EggsAndDetritus);
EggsAndDetritus              = EggsAndDetritus(sort_order);
looky_EggsAsDetritus         = find(EggsAndDetritus  == GroupTypeDef_eggs);
temp_EggFractions            = temp_EwE_DetritusFate(:, looky_EggsAsDetritus); % select egg columns within EwE_DetritusFate

% step 1h: prepare landings and discards
temp_Landings                                      = zeros(num_ResGroups, num_gear); % initialize; this appends gear groups at bottom, set to 0
temp_Discards                                      = zeros(num_ResGroups, num_gear); % initialize; this appends gear groups at bottom, set to 0
vertical_landings                                  = zeros(num_AggGroups, num_gear); % initialize first agg step
vertical_discards                                  = zeros(num_AggGroups, num_gear); % initialize first agg step
temp_Landings(1:num_LivingAndDetritus, 1:num_gear) = dat.landings;
temp_Discards(1:num_LivingAndDetritus, 1:num_gear) = dat.discards;
temp_TotalFisheries                                = sum((temp_Landings + temp_Discards), 1); % (this vector will get written over after aggregation); (horizontal vector)

% step 1i: assign production values to eggs, detritus, and fisheries (use CONSUMtotal and sum landings values)
temp_Biomass(looky_fisheries)                 = temp_TotalFisheries; % include fisheries "biomasses" as landings + discards
temp_TotalConsumption((end+1):(end+num_gear)) = temp_TotalFisheries; % include fisheries "consumption" as landings + discards
temp_Production(looky_fisheries)              = temp_TotalFisheries'; % (vertical vector)
temp_Production(looky_Detritus)               = temp_TotalConsumption(looky_Detritus)';
temp_Production(looky_Eggs)                   = temp_TotalConsumption(looky_Eggs)';
temp_EM(looky_fisheries)                      = sum(temp_Landings, 1); % landings are production removed from system as emigration (EM); (NOTE: this writes over any EM values for fisheries defined in "ECOTRANrecycling" worksheet)
% temp_EM(looky_TerminalBnthDetritus)           = sum(temp_Consumption(:, looky_TerminalBnthDetritus), 1) - sum(temp_Consumption(looky_TerminalBnthDetritus, :), 2); % NOTE: line disabled 10-17-2013, causes double accounting with "OtherMortality" down the line; non-consumed terminal benthic detritus production is removed from system as emigration (EM); (NOTE: this writes over any EM values for terminal benthic detritus defined in "ECOTRANrecycling" worksheet)

% step lqqq: put import production (via external consumption) into EM as a production import term (negative EM)
% NOTE: import consumption must be converted into production terms
temp_EM(1:num_LivingAndDetritus) = temp_EM(1:num_LivingAndDetritus) - (temp_ImportConsumption' .* dat.PQ(1:num_LivingAndDetritus));

% step lii: prepare pedigree variables
temp_PedigreeParameters                     = dat.PedigreeParameters;
temp_PedigreeLandings                       = dat.PedigreeLandings;
temp_PedigreeDiscards                       = dat.PedigreeDiscards;

temp_PedigreeParameters(looky_fisheries, :) = NaN; % append dummy rows for fisheries (so rows are arranged identaically to physiological parameters)
temp_PedigreeLandings(looky_fisheries, :)   = NaN; % append dummy rows for fisheries (so rows are arranged identaically to physiological parameters)
temp_PedigreeDiscards(looky_fisheries, :)   = NaN; % append dummy rows for fisheries (so rows are arranged identaically to physiological parameters)

temp_PedigreeLandings                       = temp_PedigreeLandings .* temp_Landings; % weight temp_PedigreeLandings by temp_Landings
temp_PedigreeDiscards                       = temp_PedigreeDiscards .* temp_Discards; % weight temp_PedigreeDiscards by temp_Discards


% step 1j: initialize Agg variables
AggNumber(1:num_AggGroups, 1)    = NaN; % initialize
AggLabel                         = cell(num_AggGroups, 1); % initialize
AggGroupType(1:num_AggGroups, 1) = NaN; % initialize GroupType vector for building up in same order as aggregated model
Biomass                          = zeros(num_AggGroups, 1); % initialize
BiomassWOegg                     = zeros(num_AggGroups, 1); % initialize
Production                       = zeros(num_AggGroups, 1); % initialize
ProductionWOegg                  = zeros(num_AggGroups, 1); % initialize
ConsumptionWOegg                 = zeros(num_AggGroups, 1); % initialize
PB(1:num_AggGroups, 1)           = NaN; % initialize
QB(1:num_AggGroups, 1)           = NaN; % initialize
PQ(1:num_AggGroups, 1)           = NaN; % initialize
TL(1:num_AggGroups, 1)           = NaN; % initialize
EwE_EE(1:num_AggGroups, 1)       = NaN; % initialize
AE(1:num_AggGroups, 1)           = NaN; % initialize
EwE_EggFractions                 = zeros(num_AggGroups, num_eggs); % initialize
EwE_DetritusFate                 = zeros(num_AggGroups, num_EggsAndDetritus); % initialize
BA                               = zeros(num_AggGroups, 1); % initialize
EM                               = zeros(num_AggGroups, 1); % initialize
EggProduction_forced             = zeros(num_AggGroups, 1); % initialize
Metabolism_forced                = zeros(num_AggGroups, 1); % initialize
DetritusFate_feces               = zeros(num_AggGroups, 2); % initialize
DetritusFate_senescence          = zeros(num_AggGroups, 2); % initialize
ExcretionFate                    = zeros(num_AggGroups, 2); % initialize
ProductionLossScaler             = zeros(num_AggGroups, 1); % initialize
RetentionScaler                  = zeros(num_AggGroups, 1); % initialize
FunctionalResponseParams         = zeros(num_AggGroups, 4); % initialize
FunctionalResponse_matrix        = zeros(num_AggGroups, num_AggGroups); % initialize
Agg_PedigreeParameters           = zeros(num_AggGroups, 37); % initialize
vertical_PedigreeLandings        = zeros(num_AggGroups, num_gear); % for fishery aggregation step 1 (vertical aggregation)
vertical_PedigreeDiscards        = zeros(num_AggGroups, num_gear); % for fishery aggregation step 1 (vertical aggregation)

% step 1k: some error checking
if num_ResGroups ~= length(NumberCodes); error('error in matching dat.num_EwEGroups; check detritus count in .xlsm sheet:main cell:B4'); end % just an error check, may never be triggered





% *************************************************************************
% STEP 2: aggregate biomass, physiology, fisheries (vertically)------------
for TrophicGrp_loop = 1:num_AggGroups;
	current_AggCode                  = uniqueAggCodes(TrophicGrp_loop); % current aggregation group
    looky_currentAggCode             = find(AggCodes == current_AggCode); % row numbers of all groups included in current aggregated group
    AggNumber(TrophicGrp_loop, 1)    = current_AggCode; % aggregation number (vertical vector)
    AggLabel(TrophicGrp_loop)        = AggName(looky_currentAggCode(1)); % aggregate labels    
    
    % aggregate biomass, production, BA, & EM (summed)
    current_Biomass                  = temp_Biomass(looky_currentAggCode);
    current_Production               = temp_Production(looky_currentAggCode);
    current_Consumption              = temp_TotalConsumption(looky_currentAggCode);
    current_BA                       = temp_BA(looky_currentAggCode);
    current_EM                       = temp_EM(looky_currentAggCode);
    Biomass(TrophicGrp_loop, 1)      = nansum(current_Biomass); % aggregate summed biomass (vertical vector)
	Production(TrophicGrp_loop, 1)   = nansum(current_Production); % aggregate summed production (vertical vector)
    BA(TrophicGrp_loop, 1)           = nansum(current_BA); % aggregate summed BA (vertical vector)
    EM(TrophicGrp_loop, 1)           = nansum(current_EM); % aggregate summed EM (vertical vector)
    
    % aggregate GroupType codes
    current_GroupType                = GroupTypes(looky_currentAggCode);
    if sum(ismember(current_GroupType, 4.1)) > 0
        AggGroupType(TrophicGrp_loop, 1) = 4.1; % favor terminal pelagic detritus GroupType
    elseif sum(ismember(current_GroupType, 4.3)) > 0
        AggGroupType(TrophicGrp_loop, 1) = 4.3; % favor terminal benthic detritus GroupType
    else
        AggGroupType(TrophicGrp_loop, 1) = mode(current_GroupType); % use the most common group type in the aggregation group (in case groups of different types get aggregated together)
    end
    
    
    
    % aggregate physiology, EwE_EggFractions, & ECOTRAN recycling terms (production-weighted means)
    current_PB                       = dat.PB(looky_currentAggCode);
    current_QB                       = dat.QB(looky_currentAggCode);
    current_PQ                       = dat.PQ(looky_currentAggCode);
    current_TL                       = dat.TL(looky_currentAggCode);
    current_EwE_EE                   = dat.EE(looky_currentAggCode);
    current_AE                       = dat.AE(looky_currentAggCode);
    
    current_EggFractions             = temp_EggFractions(looky_currentAggCode, :);
    current_EwE_DetritusFate         = temp_EwE_DetritusFate(looky_currentAggCode, :);

    current_DetritusFate_feces        = temp_DetritusFate_feces(looky_currentAggCode, 1:2);
    current_DetritusFate_senescence   = temp_DetritusFate_senescence(looky_currentAggCode, 1:2);
    current_ExcretionFate             = temp_ExcretionFate(looky_currentAggCode, 1:2);
    current_ProductionLossScaler      = temp_ProductionLossScaler(looky_currentAggCode);
    current_RetentionScaler           = temp_RetentionScaler(looky_currentAggCode);
    current_FunctionalResponseParams  = temp_FunctionalResponseParams(looky_currentAggCode, 1:4);
    current_FunctionalResponse_matrix = temp_FunctionalResponse_matrix(looky_currentAggCode, :);
    current_EggProduction_forced      = temp_EggProduction_forced(looky_currentAggCode);
    current_Metabolism_forced         = temp_Metabolism_forced(looky_currentAggCode);
    current_PedigreeParameters        = temp_PedigreeParameters(looky_currentAggCode, :);

    
    
    looky_notEGGS = find(current_GroupType ~= GroupTypeDef_eggs); % filter out groups lacking physiology (i.e., eggs)
	if ~isempty(looky_notEGGS)
        
        BiomassWOegg(TrophicGrp_loop, 1)     = sum(current_Biomass(looky_notEGGS)); % aggregate biomass excluding eggs (vertical vector)
        ProductionWOegg(TrophicGrp_loop, 1)  = sum(current_Production(looky_notEGGS)); % aggregate Production excluding eggs (vertical vector)
        ConsumptionWOegg(TrophicGrp_loop, 1) = sum(current_Consumption(looky_notEGGS)); % aggregate Production excluding eggs (vertical vector)
        
        
        PB(TrophicGrp_loop, 1)                      = sum(current_PB(looky_notEGGS)                         .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean P/B (ignoring eggs lacking physiology)
        QB(TrophicGrp_loop, 1)                      = sum(current_QB(looky_notEGGS)                         .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean Q/B (ignoring eggs lacking physiology)
        PQ(TrophicGrp_loop, 1)                      = sum(current_PQ(looky_notEGGS)                         .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean P/Q (ignoring eggs lacking physiology)
        TL(TrophicGrp_loop, 1)                      = sum(current_TL(looky_notEGGS)                         .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean TL (ignoring eggs lacking physiology)
        AE(TrophicGrp_loop, 1)                      = sum(current_AE(looky_notEGGS)                         .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean AE (ignoring eggs lacking physiology)
        
        DetritusFate_feces(TrophicGrp_loop, 1)      = sum(current_DetritusFate_feces(looky_notEGGS, 1)      .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean DetritusFate_feces (ignoring eggs lacking physiology)
        DetritusFate_feces(TrophicGrp_loop, 2)      = sum(current_DetritusFate_feces(looky_notEGGS, 2)      .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean DetritusFate_feces (ignoring eggs lacking physiology)
%         DetritusFate_senescence(TrophicGrp_loop, 1) = sum(current_DetritusFate_senescence(looky_notEGGS, 1) .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean DetritusFate_senescence (ignoring eggs lacking physiology)
%         DetritusFate_senescence(TrophicGrp_loop, 2) = sum(current_DetritusFate_senescence(looky_notEGGS, 2) .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean DetritusFate_senescence (ignoring eggs lacking physiology)
        ExcretionFate(TrophicGrp_loop, 1)           = sum(current_ExcretionFate(looky_notEGGS, 1)           .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean ExcretionFate (ignoring eggs lacking physiology)
        ExcretionFate(TrophicGrp_loop, 2)           = sum(current_ExcretionFate(looky_notEGGS, 2)           .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean ExcretionFate (ignoring eggs lacking physiology)
%         ProductionLossScaler(TrophicGrp_loop, 1)    = sum(current_ProductionLossScaler(looky_notEGGS, 1)    .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean ProductionLossScaler (ignoring eggs lacking physiology)
%         RetentionScaler(TrophicGrp_loop, 1)         = sum(current_RetentionScaler(looky_notEGGS, 1)         .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean RetentionScaler (ignoring eggs lacking physiology)
        EggProduction_forced(TrophicGrp_loop, 1)    = sum(current_EggProduction_forced(looky_notEGGS, 1)    .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean EggProduction_forced (ignoring eggs lacking physiology)
        Metabolism_forced(TrophicGrp_loop, 1)       = sum(current_Metabolism_forced(looky_notEGGS, 1)       .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean Metabolism_forced (ignoring eggs lacking physiology)
        
        % aggregate EggsAsDetritus
        if num_eggs > 0
            for egg_loop = 1:num_eggs
                EwE_EggFractions(TrophicGrp_loop, egg_loop) = sum(current_EggFractions(looky_notEGGS, egg_loop) .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean EwE_EggFractions (ignoring eggs lacking physiology)
            end
        end
        
        
%         % PPP aggregate pedigree
%         for pedigree_loop = 1:37
%             Agg_PedigreeParameters(TrophicGrp_loop, pedigree_loop) = sum(current_PedigreeParameters(looky_notEGGS, pedigree_loop) .* current_Production(looky_notEGGS)) / ProductionWOegg(TrophicGrp_loop); % weighted mean PedigreeParameters (ignoring eggs lacking physiology)
%         end
        
    end % end  ~isempty(looky_notEGGS)
    
    
        % PPP aggregate pedigree
        for pedigree_loop = 1:37
            Agg_PedigreeParameters(TrophicGrp_loop, pedigree_loop) = sum(current_PedigreeParameters(:, pedigree_loop) .* current_Production) / Production(TrophicGrp_loop); % weighted mean PedigreeParameters (including eggs)
        end

    
    
    
    % aggregate EggsAndDetritus (Note difference in variable names, EggsAndDetritus vs EggsAsDetritus)
    if num_EggsAndDetritus > 0
        for detritus_loop = 1:num_EggsAndDetritus
            EwE_DetritusFate(TrophicGrp_loop, detritus_loop) = sum(current_EwE_DetritusFate(:, detritus_loop) .* current_Production) / sum(current_Production); % weighted mean current_EwE_DetritusFate (INCLUDING eggs & detritus lacking physiology)
        end
    end
    
    DetritusFate_senescence(TrophicGrp_loop, 1)  = sum(current_DetritusFate_senescence(:, 1) .* current_Production) / sum(current_Production); % weighted mean DetritusFate_senescence (INCLUDING eggs & detritus lacking physiology)
    DetritusFate_senescence(TrophicGrp_loop, 2)  = sum(current_DetritusFate_senescence(:, 2) .* current_Production) / sum(current_Production); % weighted mean DetritusFate_senescence (INCLUDING eggs & detritus lacking physiology)
    ProductionLossScaler(TrophicGrp_loop, 1)     = sum(current_ProductionLossScaler(:, 1)    .* current_Production) / sum(current_Production); % weighted mean ProductionLossScaler (INCLUDING eggs & detritus lacking physiology)
    RetentionScaler(TrophicGrp_loop, 1)          = sum(current_RetentionScaler(:, 1)         .* current_Production) / sum(current_Production); % weighted mean RetentionScaler (INCLUDING eggs & detritus lacking physiology)
    % FunctionalResponseParams (QQQ in future use a rempat here and add agg steps for FunctionalResponse_matrix)
    FunctionalResponseParams(TrophicGrp_loop, 1) = sum(current_FunctionalResponseParams(:, 1) .* current_Production) / sum(current_Production); % weighted mean FunctionalResponseParams (INCLUDING eggs & detritus lacking physiology)
    FunctionalResponseParams(TrophicGrp_loop, 2) = sum(current_FunctionalResponseParams(:, 2) .* current_Production) / sum(current_Production); % weighted mean FunctionalResponseParams (INCLUDING eggs & detritus lacking physiology)
    FunctionalResponseParams(TrophicGrp_loop, 3) = sum(current_FunctionalResponseParams(:, 3) .* current_Production) / sum(current_Production); % weighted mean FunctionalResponseParams (INCLUDING eggs & detritus lacking physiology)
    FunctionalResponseParams(TrophicGrp_loop, 4) = sum(current_FunctionalResponseParams(:, 4) .* current_Production) / sum(current_Production); % weighted mean FunctionalResponseParams (INCLUDING eggs & detritus lacking physiology)
    EwE_EE(TrophicGrp_loop, 1)                  = sum(current_EwE_EE .* current_Production)                        / sum(current_Production); % weighted mean EwE_EE (INCLUDING eggs & detritus lacking physiology)

    
    % aggregate fisheries and fisheries pedigree vertically (summed)
    current_landings                                       = temp_Landings(looky_currentAggCode, :);
    current_discards                                       = temp_Discards(looky_currentAggCode, :);
    current_PedigreeLandings                               = temp_PedigreeLandings(looky_currentAggCode, :);
    current_PedigreeDiscards                               = temp_PedigreeDiscards(looky_currentAggCode, :);
    vertical_landings(TrophicGrp_loop, 1:num_gear)         = sum(current_landings, 1); %
    vertical_discards(TrophicGrp_loop, 1:num_gear)         = sum(current_discards, 1); %
    vertical_PedigreeLandings(TrophicGrp_loop, 1:num_gear) = sum(current_PedigreeLandings, 1); % weighted vertical_PedigreeLandings
    vertical_PedigreeDiscards(TrophicGrp_loop, 1:num_gear) = sum(current_PedigreeDiscards, 1); % weighted vertical_PedigreeDiscards
      
    
end % end TrophicGrp_loop

% step 2e: find row Aggregation model addresses for phytoplankton, egg, detritus, and fisheries group types
clear looky_ % clear defunct looky_ terms, now looky_ refers to Agg model
looky_PrimaryProducers  = find(floor(AggGroupType) == GroupTypeDef_ANYPrimaryProd);
looky_Eggs              = find(AggGroupType        == GroupTypeDef_eggs);
looky_Detritus          = find(floor(AggGroupType) == GroupTypeDef_ANYDetritus); %  detritus groups
looky_fisheries         = find(floor(AggGroupType) == GroupTypeDef_fishery);
looky_fisheries_FullRes = find(floor(GroupTypes)   == GroupTypeDef_fishery);


% step 2f: adjust parameters for individual groups
% change parameter values for phytoplankton, detritus, and egg groups
AE(looky_PrimaryProducers) = 1; % make AE for phytoplankton = 1 (no feces)
PQ(looky_PrimaryProducers) = 1; % make PQ for phytoplankton = 1 (all consumed goes to production)
AE(looky_Detritus)         = 1; % make AE for PelagicDetritus = 1 (no feces)
PQ(looky_Detritus)         = 1; % make PQ for PelagicDetritus = 1 (all consumed goes to production)
TL(looky_Eggs)             = 1; % make egg TL = 1
AE(looky_Eggs)             = 1; % make AE for eggs = 1 (no feces) (1-21-2011)
PQ(looky_Eggs)             = 1; % make PQ for eggs = 1 (all consumed goes to production) (1-21-2011)
EwE_EggFractions(looky_fisheries, 1:num_eggs) = 0; % replace NaNs caused by fisheries QQQ not needed?

% step 2g: aggregate fisheries horizontally
AggCodes_fisheries       = AggCodes(looky_fisheries_FullRes); % AggCodes of fisheries in the full-res list
uniqueAggCodes_fisheries = unique(AggCodes_fisheries);
num_AggGroups_fisheries  = length(uniqueAggCodes_fisheries);
AggLandings              = zeros(num_AggGroups, num_AggGroups_fisheries); % initialize
AggDiscards              = zeros(num_AggGroups, num_AggGroups_fisheries); % initialize

Agg_PedigreeLandings     = zeros(num_AggGroups, num_AggGroups_fisheries); % initialize
Agg_PedigreeDiscards     = zeros(num_AggGroups, num_AggGroups_fisheries); % initialize

for FisheryGrp_loop = 1:num_AggGroups_fisheries;
    current_AggCode_fisheries                     = uniqueAggCodes_fisheries(FisheryGrp_loop);
    looky_currentAggCode                          = find(AggCodes_fisheries == current_AggCode_fisheries); % clm numbers of all gear types included in current aggregated fishery
    AggLandings(1:num_AggGroups, FisheryGrp_loop) = sum(vertical_landings(:, looky_currentAggCode), 2);
    AggDiscards(1:num_AggGroups, FisheryGrp_loop) = sum(vertical_discards(:, looky_currentAggCode), 2);
    
    % aggregate fishery pedigree here
    Agg_PedigreeLandings(1:num_AggGroups, FisheryGrp_loop) = sum(vertical_PedigreeLandings(:, looky_currentAggCode), 2) ./ AggLandings(:, FisheryGrp_loop);
    Agg_PedigreeDiscards(1:num_AggGroups, FisheryGrp_loop) = sum(vertical_PedigreeDiscards(:, looky_currentAggCode), 2) ./ AggDiscards(:, FisheryGrp_loop);
end

Agg_PedigreeLandings(isnan(Agg_PedigreeLandings)) = 0; % filter NaNs from div/0 cases
Agg_PedigreeDiscards(isnan(Agg_PedigreeDiscards)) = 0; % filter NaNs from div/0 cases

total_AggLandings = sum(AggLandings, 1);
total_AggDiscards = sum(AggDiscards, 1);





% *************************************************************************
% STEP 3: aggregate consumption array--------------------------------------
% AggGroupType and uniqueAggCodes without fisheries for consumption & diet aggregation
AggGroupType_NoFisheries                    = AggGroupType;
AggGroupType_NoFisheries(looky_fisheries)   = [];
uniqueAggCodes_NoFisheries                  = uniqueAggCodes; % will need list without fisheries for consumption & diet aggregation
uniqueAggCodes_NoFisheries(looky_fisheries) = [];
num_AggGroups_NoFisheries                   = length(uniqueAggCodes_NoFisheries);

% parse consumption matrix, total consumption read in from the .csv file
ConsumptionConsumerCode              = dat.consumption(1, 2:end); % trophic group number across top of consumption matrix
ConsumptionProducerCode              = dat.consumption(2:end, 1); % trophic group number along side of consumption matrix
Consumption                          = dat.consumption(2:end, 2:end); % consumption matrix without group number headings
[consumption_rows, consumption_clms] = size(Consumption);

% initialize AggConsumption, AggImportConsumption, and AggPredation
AggConsumption(1:(num_AggGroups_NoFisheries+1), 1:num_AggGroups_NoFisheries) = NaN; % initialize AggConsumption
AggPredation(1:num_AggGroups_NoFisheries, 1:num_AggGroups_NoFisheries)       = NaN; % initialize AggPredation
AggImportConsumption(1, 1:num_AggGroups_NoFisheries)                         = NaN; % initialize AggImportConsumption
AggPreyCode_consumption(1:num_AggGroups_NoFisheries, 1)                      = NaN; % initialize
AggPredatorCode_consumption(1, 1:num_AggGroups_NoFisheries)                  = NaN; % initialize

for Prey_loop = 1:num_AggGroups_NoFisheries
    current_AggPreyCode                   = uniqueAggCodes_NoFisheries(Prey_loop); % get AggCode for current prey group
    AggPreyCode_consumption(Prey_loop, 1) = current_AggPreyCode; % build AggPreyCode vector for saved results (vertical vector)
    looky_currentPrey                     = find(AggCodes == current_AggPreyCode); % row addresses of current prey groups in the full-res consumption matrix (remeber that consumption matrix is in same order as AggCodes, except without fisheries)

    if ~isempty(looky_currentPrey)
        current_horizontal_consumption = sum(Consumption(looky_currentPrey, :), 1); % sum of prey consumed (horizontal vector)

        for Predator_loop = 1:num_AggGroups_NoFisheries % QQQ still need to NOT aggregate eggs and consumers (just use a warning)
            current_AggPredatorCode = uniqueAggCodes_NoFisheries(Predator_loop);
            looky_currentPredator   = find(AggCodes == current_AggPredatorCode); % clm addresses of current predator groups in the full-res consumption matrix

            if ~isempty(looky_currentPredator)
                AggConsumption(Prey_loop, Predator_loop) = sum(current_horizontal_consumption(looky_currentPredator));

                if Prey_loop == num_AggGroups_NoFisheries;
                    AggPredatorCode_consumption(1, Predator_loop) = current_AggPredatorCode; % build predator agg num vector for saved results (horizontal vector)
                    AggImportConsumption(1, Predator_loop)        = sum(temp_ImportConsumption(looky_currentPredator));
                end
            end
        end
    end
end
AggConsumption(end, :)      = AggImportConsumption; % append import consumption
CONSUMtotal                 = sum(AggConsumption, 1); % total consumption by each aggregate predator group (horizontal vector)





% *************************************************************************
% STEP 4: other book keeping-----------------------------------------------
% step 4a: assign production values to fisheries (use CONSUMtotal and sum landings values)
Production(looky_fisheries) = total_AggLandings; % note that here we only want landings, while above when we aggregated groups we wanted landings + discards

% step 4c: VERY IMPORTANT LINE---> PB recalculated from defn. of P/B to correct for production rate of groups with eggs
PB = Production ./ Biomass;

% step 4d: PB & PQ & AE for fisheries = landings / (landings + discards)
PQ(looky_fisheries) = total_AggLandings ./ (total_AggLandings + total_AggDiscards);
PB(looky_fisheries) = total_AggLandings ./ (total_AggLandings + total_AggDiscards);
AE(looky_fisheries) = total_AggLandings ./ (total_AggLandings + total_AggDiscards); % AE of fisheries = ratio landings/(landings + discard)

% step 4d: EwE_EE for fisheries = 0 as all fishery production is removed from system
EwE_EE(looky_fisheries) = 0;

% step 4e: change parameter values for phytoplankton, detritus, egg groups, & fisheries
QB(looky_PrimaryProducers) = PB(looky_PrimaryProducers) .* (1./PQ(looky_PrimaryProducers)); % calculate QB for phytoplankton
QB(looky_Detritus)         = PB(looky_Detritus)         .* (1./PQ(looky_Detritus)); % calculate QB for detritus
QB(looky_Eggs)             = PB(looky_Eggs)             .* (1./PQ(looky_Eggs)); % calculate QB for egg groups
QB(looky_fisheries)        = PB(looky_fisheries)        .* (1./PQ(looky_fisheries)); % calculate QB for fisheries





% *************************************************************************
% STEP 5: aggregate diet matrix--------------------------------------------
% step 5a: parse diet matrix and import diet vector read in from the .csv file
DietConsumerCode        = dat.diet(1, 2:end); % trophic group number across top of diet matrix (given in excel file)
DietProducerCode        = dat.diet(2:end, 1); % trophic group number along side of diet matrix (given in excel file)
Diet                    = dat.diet(2:end, 2:end); % diet matrix without group number headings
ImportDiet              = dat.import_diet(2:end);
temp_PedigreeDiet       = dat.PedigreeDiet(2:end, 2:end); % PPP diet pedigree matrix without group number headings
temp_PedigreeDiet       = temp_PedigreeDiet .* Diet; % weight by diet fractions (PPP in future can try alternative scaling here to allow for consumption of groups currently 0 in diet matrix)
temp_PedigreeDietImport = dat.import_PedigreeDiet(2:end);
temp_PedigreeDietPref   = dat.PedigreeDietPrefRules(2:end, 2:end); % PPP PedigreeDietPrefRules matrix without group number headings

% step 5b: initialize AggDiet, AggImportDiet, Agg_PedigreeDiet, and Agg_PedigreeDietImport
AggDiet(1:(num_AggGroups_NoFisheries+1), 1:(num_AggGroups_NoFisheries+1))              = NaN; % define AggDiet (add 1 row for agg prey number-code; add 1 clm for pred number-code)
AggImportDiet(1, 1:(num_AggGroups_NoFisheries+1))                                      = NaN; % define AggImportDiet (add 1 clm for pred number-code)
AggPredatorCode_diet(1, 1:num_AggGroups_NoFisheries)                                   = NaN;
AggPreyCode_diet(1:num_AggGroups_NoFisheries, 1)                                       = NaN;
Agg_PedigreeDiet(1:(num_AggGroups_NoFisheries+1), 1:(num_AggGroups_NoFisheries+1))     = NaN; % PPP define Agg_PedigreeDiet (add 1 row for agg prey number-code; add 1 clm for pred number-code)
Agg_PedigreeDietImport(1, 1:(num_AggGroups_NoFisheries+1))                             = NaN; % PPP define Agg_PedigreeDietImport (add 1 clm for pred number-code)
Agg_PedigreeDietPref(1:(num_AggGroups_NoFisheries+1), 1:(num_AggGroups_NoFisheries+1)) = NaN; % PPP define Agg_PedigreeDietPref (add 1 row for agg prey number-code; add 1 clm for pred number-code)

% step 5c: aggregate by weighted biomass, production, or total consumption
% option A) weight by biomass
% biomass_diet                             = dat.Biomass';
% biomass_diet(looky_fisheries_FullRes)    = []; % remove fisheries
% current_ImportDiet                       = ImportDiet .* biomass_diet; % scale ImportDiet by predator biomass in fully-resolved model (horizontal vector)
% current_PedigreeDietImport               = temp_PedigreeDietImport .* biomass_diet; % scale temp_PedigreeDietImport by predator biomass in fully-resolved model (horizontal vector)
% weighting_agent                          = biomass_diet;
% weighting_scaler                         = BiomassWOegg;

% option B) weight by production 
% production_diet                          = (dat.Biomass .* dat.PB)';
% production_diet(looky_fisheries_FullRes) = []; % remove fisheries
% current_ImportDiet                       = ImportDiet .* production_diet; % scale ImportDiet by predator production in fully-resolved model (horizontal vector)
% current_PedigreeDietImport               = temp_PedigreeDietImport .* production_diet; % scale temp_PedigreeDietImport by predator production in fully-resolved model (horizontal vector)
% weighting_agent                          = production_diet;
% weighting_scaler                         = ProductionWOegg;

% option C) weight by total consumption 
consumption_diet                          = temp_TotalConsumption; % (horizontal vector)
consumption_diet(looky_fisheries_FullRes) = []; % remove fisheries
current_ImportDiet                        = temp_ImportConsumption; % (horizontal vector)
current_PedigreeDietImport                = temp_PedigreeDietImport .* consumption_diet; % scale temp_PedigreeDietImport by predator consumption_diet in fully-resolved model (horizontal vector)
weighting_agent                           = consumption_diet;
weighting_scaler                          = ConsumptionWOegg;

% step 5d: do the aggregation
for Prey_loop = 1:num_AggGroups_NoFisheries;
    current_AggPreyCode            = uniqueAggCodes_NoFisheries(Prey_loop);
    AggPreyCode_diet(Prey_loop, 1) = current_AggPreyCode; % build AggPreyCode_diet vector for saved results (vertical vector)
    looky_currentPrey              = find(AggCodes == current_AggPreyCode); % row addresses of current prey groups in the full-res diet matrix (remember that diet matrix is in same order as AggCodes, except without fisheries)
    
    if ~isempty(looky_currentPrey)
        current_horizontal_diet             = sum(Diet(looky_currentPrey, :), 1); % sum of prey proportions (horizontal vector)
        current_horizontal_PedigreeDiet     = sum(temp_PedigreeDiet(looky_currentPrey, :), 1) ./ current_horizontal_diet; % PPP sum of weighted PedigreeDiet normalized by current_horizontal_diet (horizontal vector)
        current_horizontal_diet             = current_horizontal_diet         .* weighting_agent; % scale by predator biomass, production, or consumption in fully-resolved model, for weighting purposes (horizontal vector)
        current_horizontal_PedigreeDiet     = current_horizontal_PedigreeDiet .* weighting_agent; % PPP scale by predator biomass, production, or consumption in fully-resolved model, for weighting purposes (horizontal vector)
        current_horizontal_PedigreeDietPref = mode(temp_PedigreeDietPref(looky_currentPrey, :), 1); % mode of PedigreeDietPref (horizontal vector)
        
        for Predator_loop = 1:num_AggGroups_NoFisheries % QQQ still need to NOT aggregate eggs and consumers (just use a warning)
            current_AggPredatorCode = uniqueAggCodes_NoFisheries(Predator_loop);
            looky_currentPredator   = find(AggCodes == current_AggPredatorCode); % clm addresses of current predator groups in the full-res diet matrix
            
            looky_PredatorBiomass   = find(uniqueAggCodes == uniqueAggCodes_NoFisheries(Predator_loop)); % address of current predator in AggModel (scaler)
            current_PredatorBiomass = weighting_scaler(looky_PredatorBiomass); % (scaler)

            if ~isempty(looky_currentPredator)
                
                AggDiet((Prey_loop+1), (Predator_loop+1))              = sum(current_horizontal_diet(looky_currentPredator))         / current_PredatorBiomass; % normalize by summed agg-model predator biomass
                Agg_PedigreeDiet((Prey_loop+1), (Predator_loop+1))     = sum(current_horizontal_PedigreeDiet(looky_currentPredator)) / current_PredatorBiomass; % normalize by summed agg-model predator biomass
                Agg_PedigreeDietPref((Prey_loop+1), (Predator_loop+1)) = mode(current_horizontal_PedigreeDietPref(looky_currentPredator));
                
                
                if Prey_loop == num_AggGroups_NoFisheries; % do this on the last Prey_loop
                    AggPredatorCode_diet(1, Predator_loop)       = current_AggPredatorCode; % build predator agg num vector for saved results (horizontal vector)
                    AggImportDiet(1, (Predator_loop+1))          = sum(current_ImportDiet(looky_currentPredator)) / current_PredatorBiomass; % normalize by summed agg-model predator biomass
                    Agg_PedigreeDietImport(1, (Predator_loop+1)) = sum(current_PedigreeDietImport(looky_currentPredator)) / current_PredatorBiomass; % PPP normalize by summed agg-model predator biomass
                end
                
            end % (if ~isempty(looky_currentPredator))
            
        end % (Predator_loop)
    end % (~isempty(looky_currentPrey))
end % (Prey_loop)

% step 5e: add aggregated predator and prey header numbers
AggDiet(1, 2:end)                         = AggPredatorCode_diet;
AggDiet(2:end, 1)                         = AggPreyCode_diet;
AggDiet((end+1), :)                       = AggImportDiet; % append ImportDiet
AggDiet(isnan(AggDiet))                   = 0; % correct for div/0 errors (phytoplankton & detritus groups)
AggDiet(1, 1)                             = NaN;
Agg_PedigreeDiet(1, 2:end)                = AggPredatorCode_diet;
Agg_PedigreeDiet(2:end, 1)                = AggPreyCode_diet;
Agg_PedigreeDiet((end+1), :)              = Agg_PedigreeDietImport; % append PedigreeDietImport QQQ needs to be multiplied by diet to set non-diet cells to 0
Agg_PedigreeDiet(isnan(Agg_PedigreeDiet)) = 0; % correct for div/0 errors (phytoplankton & detritus groups)
Agg_PedigreeDiet(1, 1)                    = NaN;
Agg_PedigreeDietPref(1, 2:end)            = AggPredatorCode_diet;
Agg_PedigreeDietPref(2:end, 1)            = AggPreyCode_diet;
Agg_PedigreeDietPref((end+1), :)          = 0; % append diet preference rules for import diet all set to 0 by default
Agg_PedigreeDietPref(1, 1)                = NaN;

% step 5f: prepare guild codes
temp_PreyGuild_code = dat.PreyGuild_code;
[num_guilds, toss]  = size(dat.PreyGuild_code);
temp_PreyGuild_code = cell(num_guilds, 1);
for guild_loop = 1:num_guilds
    current_guild = eval(dat.PreyGuild_code{guild_loop}); % convert from strings
    temp_PreyGuild_code{guild_loop} = unique(current_guild); % build as vectors; filter any duplications
end





% *************************************************************************
% STEP 6: pack EwEResult for export----------------------------------------
% step 6a: labels, GroupType, and number codes
EwEResult.AggLabel    = AggLabel;
EwEResult.GroupType   = AggGroupType; % includes fisheries rows
EwEResult.FullResNums = NumberCodes - num_NitrogenNutrients; % trophic group numbers in fully-resolved model (QQQ take off fisheries rows??)
EwEResult.EwE_code    = 1:num_AggGroups; % includes fisheries rows
EwEResult.AggNumber   = AggNumber;

EwEResult.GroupTypeDef_ANYNitroNutr       = dat.GroupTypeDef_ANYNitroNutr;
EwEResult.GroupTypeDef_NO3                = dat.GroupTypeDef_NO3;
EwEResult.GroupTypeDef_plgcNH4            = dat.GroupTypeDef_plgcNH4;
EwEResult.GroupTypeDef_bnthNH4            = dat.GroupTypeDef_bnthNH4;
EwEResult.GroupTypeDef_ANYPrimaryProd     = dat.GroupTypeDef_ANYPrimaryProd;
EwEResult.GroupTypeDef_LrgPhyto           = dat.GroupTypeDef_LrgPhyto;
EwEResult.GroupTypeDef_SmlPhyto           = dat.GroupTypeDef_SmlPhyto;
EwEResult.GroupTypeDef_Macrophytes        = dat.GroupTypeDef_Macrophytes;
EwEResult.GroupTypeDef_ANYConsumer        = dat.GroupTypeDef_ANYConsumer;
EwEResult.GroupTypeDef_ConsumPlgcPlankton = dat.GroupTypeDef_ConsumPlgcPlankton;
EwEResult.GroupTypeDef_ConsumPlgcNekton   = dat.GroupTypeDef_ConsumPlgcNekton;
EwEResult.GroupTypeDef_ConsumPlgcWrmBlood = dat.GroupTypeDef_ConsumPlgcWrmBlood;
EwEResult.GroupTypeDef_ConsumBntcInvert   = dat.GroupTypeDef_ConsumBntcInvert;
EwEResult.GroupTypeDef_ConsumBntcVert     = dat.GroupTypeDef_ConsumBntcVert;
EwEResult.GroupTypeDef_ConsumBnthWrmBlood = dat.GroupTypeDef_ConsumBnthWrmBlood;
EwEResult.GroupTypeDef_eggs               = dat.GroupTypeDef_eggs;
EwEResult.GroupTypeDef_ANYDetritus        = dat.GroupTypeDef_ANYDetritus;
EwEResult.GroupTypeDef_terminalPlgcDetr   = dat.GroupTypeDef_terminalPlgcDetr;
EwEResult.GroupTypeDef_offal              = dat.GroupTypeDef_offal;
EwEResult.GroupTypeDef_terminalBnthDetr   = dat.GroupTypeDef_terminalBnthDetr;
EwEResult.GroupTypeDef_BA                 = dat.GroupTypeDef_BA;
EwEResult.GroupTypeDef_EM                 = dat.GroupTypeDef_EM;
EwEResult.GroupTypeDef_fishery            = dat.GroupTypeDef_fishery;
EwEResult.GroupTypeDef_import             = dat.GroupTypeDef_import;
EwEResult.GroupTypeDef_plgcBacteria       = dat.GroupTypeDef_plgcBacteria;
EwEResult.GroupTypeDef_bnthBacteria       = dat.GroupTypeDef_bnthBacteria;

% step 6b: numbers of group types
EwEResult.num_PrimaryProducers  = length(find(floor(AggGroupType) == GroupTypeDef_ANYPrimaryProd));
EwEResult.num_eggs              = length(find(AggGroupType        == GroupTypeDef_eggs));
EwEResult.num_detritus          = length(find(floor(AggGroupType) == GroupTypeDef_ANYDetritus)); %  detritus groups
EwEResult.num_EggsAndDetritus   = EwEResult.num_eggs + EwEResult.num_detritus;
EwEResult.num_NitrogenNutrients = num_NitrogenNutrients;
EwEResult.num_fisheries         = num_AggGroups_fisheries;
EwEResult.num_plgcBacteria      = length(find(AggGroupType == GroupTypeDef_plgcBacteria));
EwEResult.num_bnthBacteria      = length(find(AggGroupType == GroupTypeDef_bnthBacteria));
EwEResult.num_Bacteria          = EwEResult.num_plgcBacteria + EwEResult.num_bnthBacteria;

% step 6c: parameters
EwEResult.Biomass         = Biomass;
EwEResult.BiomassWOegg    = BiomassWOegg;
EwEResult.Production      = Production;
EwEResult.ProductionWOegg = ProductionWOegg;
EwEResult.PB              = PB;
EwEResult.QB              = QB;
EwEResult.PQ              = PQ;
EwEResult.AE              = AE;
EwEResult.TL              = TL;
EwEResult.EwE_EE          = EwE_EE;
EwEResult.BA              = BA;
EwEResult.EM              = EM;

% step 6d: diet and consumption
EwEResult.Diet              = AggDiet;
EwEResult.Consumption       = AggConsumption; % last row is import consumption
EwEResult.ImportConsumption = AggImportConsumption;
EwEResult.TotalConsumption  = CONSUMtotal; % total consumption by each aggregate predator group (horizontal vector) (includes import consumption)

% step 6e: recycling & detritus and eggs
EwEResult.EwE_DetritusFate          = EwE_DetritusFate;
EwEResult.EwE_EggFractions          = EwE_EggFractions;
EwEResult.DetritusFate_feces        = DetritusFate_feces;
EwEResult.DetritusFate_senescence   = DetritusFate_senescence;
EwEResult.ExcretionFate             = ExcretionFate;
EwEResult.ProductionLossScaler      = ProductionLossScaler;
EwEResult.RetentionScaler           = RetentionScaler;
EwEResult.FunctionalResponseParams  = FunctionalResponseParams;
EwEResult.EggProduction_forced      = EggProduction_forced;
EwEResult.Metabolism_forced         = Metabolism_forced;
EwEResult.PelagicBacterialReduction = dat.PelagicBacterialReduction;
EwEResult.BenthicBacterialReduction = dat.BenthicBacterialReduction;
EwEResult.Oxidation_NH4             = dat.Oxidation_NH4;
EwEResult.PhytoUptake_NH4           = dat.PhytoUptake_NH4; % or use = dat.PhytoUptake_NH4(~isnan(dat.PhytoUptake_NH4))
EwEResult.PhytoUptake_NO3           = dat.PhytoUptake_NO3; % or use = dat.PhytoUptake_NO3(~isnan(dat.PhytoUptake_NO3))
EwEResult.PhytoUptake_NH4(EwEResult.PhytoUptake_NH4==0) = []; % remove empty (=0) cells (1-12-2015)
EwEResult.PhytoUptake_NO3(EwEResult.PhytoUptake_NO3==0) = []; % remove empty (=0) cells (1-12-2015)

% step 6f: nutrients info
EwEResult.AggLabel_nutrients    = AggLabel_nutrients;
EwEResult.GroupType_nutrients   = GroupType_nutrients;

% step 6g: fisheries info
EwEResult.AggLabel_fisheries                        = EwEResult.AggLabel(looky_fisheries);
EwEResult.Landings                                  = AggLandings;
EwEResult.Discards                                  = AggDiscards;
EwEResult.Biomass_fisheries                         = EwEResult.Biomass(looky_fisheries);
EwEResult.BiomassWOegg_fisheries                    = EwEResult.BiomassWOegg(looky_fisheries);
EwEResult.Production_fisheries                      = EwEResult.Production(looky_fisheries);
EwEResult.ProductionWOegg_fisheries                 = EwEResult.ProductionWOegg(looky_fisheries);
EwEResult.PB_fisheries                              = EwEResult.PB(looky_fisheries);
EwEResult.QB_fisheries                              = EwEResult.QB(looky_fisheries);
EwEResult.PQ_fisheries                              = EwEResult.PQ(looky_fisheries);
EwEResult.AE_fisheries                              = EwEResult.AE(looky_fisheries);
EwEResult.EwE_EE_fisheries                          = EwEResult.EwE_EE(looky_fisheries);
EwEResult.BA_fisheries                              = EwEResult.BA(looky_fisheries);
EwEResult.EM_fisheries                              = EwEResult.EM(looky_fisheries);
EwEResult.TL_fisheries                              = TL(looky_fisheries);
EwEResult.Landings_fisheries                        = EwEResult.Landings(looky_fisheries, :);
EwEResult.Discards_fisheries                        = EwEResult.Discards(looky_fisheries, :);
EwEResult.DetritusFate_feces_fisheries              = EwEResult.DetritusFate_feces(looky_fisheries, :);
EwEResult.DetritusFate_senescence_fisheries         = EwEResult.DetritusFate_senescence(looky_fisheries, :);
EwEResult.ExcretionFate_fisheries                   = EwEResult.ExcretionFate(looky_fisheries, :);
EwEResult.ProductionLossScaler_fisheries            = EwEResult.ProductionLossScaler(looky_fisheries);
EwEResult.RetentionScaler_fisheries                 = EwEResult.RetentionScaler(looky_fisheries);
EwEResult.FunctionalResponseParams_fisheries        = EwEResult.FunctionalResponseParams(looky_fisheries, :);
EwEResult.EggProduction_forced_fisheries            = EwEResult.EggProduction_forced(looky_fisheries);
EwEResult.Metabolism_forced_fisheries               = EwEResult.Metabolism_forced(looky_fisheries);

% remove fisheries from parameters
EwEResult.AggLabel(looky_fisheries)                 = [];
EwEResult.Biomass(looky_fisheries)                  = [];
EwEResult.BiomassWOegg(looky_fisheries)             = [];
EwEResult.Production(looky_fisheries)               = [];
EwEResult.ProductionWOegg(looky_fisheries)          = [];
EwEResult.PB(looky_fisheries)                       = [];
EwEResult.QB(looky_fisheries)                       = [];
EwEResult.PQ(looky_fisheries)                       = [];
EwEResult.AE(looky_fisheries)                       = [];
EwEResult.TL(looky_fisheries)                       = [];
EwEResult.EwE_EE(looky_fisheries)                   = [];
EwEResult.BA(looky_fisheries)                       = [];
EwEResult.EM(looky_fisheries)                       = [];
EwEResult.Landings(looky_fisheries, :)              = [];
EwEResult.Discards(looky_fisheries, :)              = [];

% remove fisheries from recycling terms
EwEResult.DetritusFate_feces(looky_fisheries, :)       = [];
EwEResult.DetritusFate_senescence(looky_fisheries, :)  = [];
EwEResult.ExcretionFate(looky_fisheries, :)            = [];
EwEResult.ProductionLossScaler(looky_fisheries)        = [];
EwEResult.RetentionScaler(looky_fisheries)             = [];
EwEResult.FunctionalResponseParams(looky_fisheries, :) = [];
EwEResult.EggProduction_forced(looky_fisheries)        = [];
EwEResult.Metabolism_forced(looky_fisheries)           = [];





% *************************************************************************
% STEP 7: pack PEDIGREE info for export------------------------------------
% step 7a: pedigree scaling terms
PEDIGREE.PhysiologyScaler                  = dat.Pedigree_PhysiologyScaler;
PEDIGREE.BiomassScaler                     = dat.Pedigree_BiomassScaler;
PEDIGREE.FisheriesScaler                   = dat.Pedigree_FisheriesScaler;
PEDIGREE.DietScaler                        = dat.Pedigree_DietScaler;
PEDIGREE.BAScaler                          = dat.Pedigree_BAScaler;
PEDIGREE.EMScaler                          = dat.Pedigree_EMScaler;
PEDIGREE.DiscardScaler                     = dat.Pedigree_DiscardScaler;
PEDIGREE.minBiomass                        = dat.Pedigree_minBiomass;
PEDIGREE.minPhysiology                     = dat.Pedigree_minPhysiology;

% step 7b: remove temporary fisheries rows
Agg_PedigreeParameters(looky_fisheries, :) = [];
Agg_PedigreeLandings(looky_fisheries, :)   = [];
Agg_PedigreeDiscards(looky_fisheries, :)   = [];

% step 7c:
PEDIGREE.PedigreeParameters                = Agg_PedigreeParameters;
PEDIGREE.PedigreeLandings                  = Agg_PedigreeLandings;
PEDIGREE.PedigreeDiscards                  = Agg_PedigreeDiscards;

% step 7d: diet pedigree
PEDIGREE.PedigreeDiet                      = Agg_PedigreeDiet;
PEDIGREE.PedigreeDietPrefRules             = Agg_PedigreeDietPref;

% step 7e: prey guild information
PEDIGREE.PreyGuild_name                    = dat.PreyGuild_name;
PEDIGREE.PreyGuild_code                    = temp_PreyGuild_code;





% end m-file***************************************************************